Eiko H11BCVSU-BP - Headlight - 55 Watt - T3.25
Description: Shop for Eiko H11BCVSU-BP ClearVision Supreme headlight bulbs to replace your current bulbs! Incredible deals on halogen lamps at 1000Bulbs.com!
Keywords: eiko h11bcvsu-bp, 031293076823, halogen headlight bulb, t3.25 halogen bulb, clearvision supreme, h11b, automotive headlight bulb, solux technology

For expert help, call: 1-800-624-4488

Don't have an account? Signup

#### Login

Email Password Remember Me

Forgot Password?

Product Search

For expert help, call: 1-800-624-4488

1-800-624-4488

# H11B Headlight - ClearVision Supreme - 55 Watt - T3.25

## Shielded - 13.2 Volt - Eiko H11BCVSU-BP

$44.50 ea
An error has occurred
Checkout
Quantity
EIKO-H11BCVSUBP1

# H11B Headlight - ClearVision Supreme - 55 Watt - T3.25

## Shielded - 13.2 Volt - Eiko H11BCVSU-BP

With SoLux technology, the Eiko H11BCVSU-BP ClearVision Supreme halogen headlight bulb illuminates the night with the same bright white light as the sun. The high-quality 55-watt lamp features a CC-8 filament shining at an impressive 1345 lumens. Designed to outshine and outlast your stock headlights, the T3.25 halogen bulb delivers a longer, more vivid beam of light for better front and peripheral coverage. The right axial prefocus, H11B (PGJY19-2) base makes it easy to replace similar bulbs on any vehicle with an H11B (PGJY19-2) headlight plug. With a filament lifespan of 1000 hours, this automotive headlight bulb will last for many miles and is suitable for all kinds of weather.

EIKO-H11BCVSUBP1

### Brochures & Spec Sheets

Eiko H11BCVSU-BP Spec Sheet

ClearVision Supreme Brochure

### Specifications

Stock Code: | EIKO-H11BCVSUBP1
Family: | ClearVision Supreme
UPC: | 031293076823
Voltage: | 13.2
Bulb Shape: | T3.25
Base Type: | Right Angle Prefocus, H11B (PGJY19-2)
Length: | 2.63 in.
Filament Type: | CC-8
Lumens (Initial): | 1345

Brand: | EiKO
Part No.: | H11BCVSU-BP
Wattage: | 55 Watt
ANSI Code: | H11B
Bulb Type: | Halogen
Color Temperature: | 4100 Kelvin
Diameter: | 0.43 in.
Life Hours: | 1,000
Case Quantity: | 10

### Customer Reviews